#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-plugin-api
version:              2.3.0.0
visibility:           public
id:                   hls-plugin-api-2.3.0.0-GROrD89xiv19memSRvxoG6
key:                  hls-plugin-api-2.3.0.0-GROrD89xiv19memSRvxoG6
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server API for plugin communication
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  516bd40ae07b64a1d0bd23d91c524245
exposed:              True
exposed-modules:
    Ide.Logger Ide.Plugin.Config Ide.Plugin.ConfigUtils
    Ide.Plugin.Error Ide.Plugin.Properties Ide.Plugin.RangeMap
    Ide.Plugin.Resolve Ide.PluginUtils Ide.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-plugin-api-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-plugin-api
hs-libraries:         HShls-plugin-api-2.3.0.0-GROrD89xiv19memSRvxoG6
depends:
    Diff-1.0-HBt7F0XCcov5pKmneLombn
    aeson-2.2.2.0-4XfhhWkmpwnB2gRUwfJP7g base-4.18.2.1
    co-log-core-0.3.2.6-JO3HPgjEzKEJ86NAvwQALV containers-0.6.7
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    dependent-map-0.4.0.1-K7Z3kub5Gwcfck0nWZl3e
    dependent-sum-0.7.2.0-Iv95wHrwUkxAc00nWCIHPx
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp extra-1.7.16-H98LN7RYlKwJ5W6Qh2fTke
    filepath-1.4.300.1 ghc-9.6.6
    hashable-1.4.7.0-DjTaTzSxyhZLemTcoX34jw
    hls-graph-2.3.0.0-HeyFkA5V638Gg24w1hlpaN
    hw-fingertree-0.1.2.1-4THbdPoSL9IU1a80Zp0pg
    lens-5.3.5-AYBI3DxVlEzIh1R399daMf
    lens-aeson-1.2.3-5NRQxAvwBQKCDBsNh2qX03
    lsp-2.2.0.0-6qQP2gkL6rf79FYuMnhEm0
    megaparsec-9.7.1-IJJCy7AfSWn4uupFAyXCnh mtl-2.3.1
    opentelemetry-0.8.0-Cx478Fg6C8v3qnQCvzsnvk
    optparse-applicative-0.18.1.0-1Cqb5McLkWg4t2rBtbfPtX
    prettyprinter-1.7.1-7gqni6JNC026grHQxT0UM8
    regex-tdfa-1.3.2.5-Lu29wvn9DRkLx2xohzaqvf
    row-types-1.0.1.2-17dnAW4BcyR4ZB2fxcPAF3 stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-E7jBNjB3KP6CTth0IZkvqw
    unordered-containers-0.2.20.1-3DXXOqLpcMZGFktSBwG2cs

haddock-interfaces:
    /usr/share/doc/haskell-hls-plugin-api/html/hls-plugin-api.haddock

haddock-html:         /usr/share/doc/haskell-hls-plugin-api/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

